ftm5: modyfy the ABS_MT_ORIENTATION range as -4096 to 4096

Align the ABS_MT_ORIENTATION range as touch_offload.

Bug: 230270099
Test: Touch works fine.

Signed-off-by: davidycchen <davidycchen@google.com>
Change-Id: Ia7e31b907272cfe4cb308bf4ec196cda6727d303
diff --git a/fts.c b/fts.c
index 69fc938..72568b2 100644
--- a/fts.c
+++ b/fts.c
@@ -6347,10 +6347,10 @@
 			     DISTANCE_MAX, 0, 0);
 #endif
 
 	/* Units are (-8192, 8192), representing the range between rotation
 	 * 90 degrees to left and 90 degrees to the right.
 	 */
-	input_set_abs_params(info->input_dev, ABS_MT_ORIENTATION, -8192, 8192,
+	input_set_abs_params(info->input_dev, ABS_MT_ORIENTATION, -4096, 4096,
 			     0, 0);
 
 #ifdef GESTURE_MODE
@@ -6347,10 +6347,10 @@
 #endif
 
-	/* Units are (-8192, 8192), representing the range between rotation
+	/* Units are (-4096, 4096), representing the range between rotation
 	 * 90 degrees to left and 90 degrees to the right.
 	 */